from http.client import NO_CONTENT
from flask import request, jsonify, Blueprint

# from jinja2.runtime import identity
from werkzeug.exceptions import BadRequest, Forbidden

# from flaschengeist.models.session import Session
# from flaschengeist.controller import userController
from flaschengeist.utils.decorators import login_required

# from flaschengeist.utils.datetime import from_iso_format
# from flaschengeist.utils.HTTP import get_filter_args, no_content
from flaschengeist.models import Session

from . import pricelist_controller, permissions


blueprint = Blueprint("pricelist_old", __name__)


@blueprint.route("/pricelist_old/drink_type", methods=["GET"])
@blueprint.route("/pricelist_old/drink_type/<int:identifier>", methods=["GET"])
def get_drink_type(identifier=None):
    if identifier:
        result = pricelist_controller.get_drink_type(identifier)
    else:
        result = pricelist_controller.get_drink_types()
    return jsonify(result)


@blueprint.route("/pricelist_old/drink_type", methods=["POST"])
@blueprint.route("/pricelist_old/drink_type/<int:identifier>", methods=["PUT"])
@login_required()
def modify_drink_type(current_session: Session, identifier=None):
    data = request.get_json()
    if request.method == "POST":
        if not current_session.user_.has_permission(permissions.DRINK_TYPE_CREATE):
            raise Forbidden
        if "id" in data:
            raise BadRequest
    if request.method == "PUT":
        if not current_session.user_.has_permission(permissions.DRINK_TYPE_EDIT):
            raise Forbidden
        if "id" not in data or not identifier:
            raise BadRequest
    return jsonify(pricelist_controller.set_drink_type(identifier, data))


@blueprint.route("/pricelist_old/drink_type/<int:identifier>", methods=["DELETE"])
@login_required(permission=permissions.DRINK_TYPE_DELETE)
def delete_drink_type(current_session, identifier: int):
    pricelist_controller.delete_drink_type(identifier)
    return "", NO_CONTENT


@blueprint.route("/pricelist_old/price", methods=["GET"])
@blueprint.route("/pricelist_old/price/<int:identifier>", methods=["GET"])
def get_price(identifier=None):
    if identifier:
        result = pricelist_controller.get_price(identifier)
    else:
        result = pricelist_controller.get_prices()
    return jsonify(result)


@blueprint.route("/pricelist_old/price", methods=["POST"])
@blueprint.route("/pricelist_old/price/<int:identifier>", methods=["PUT"])
@login_required()
def modify_price(current_session, identifier=None):
    data = request.get_json()
    if request.method == "POST":
        if not current_session.user_.has_permission(permissions.PRICE_CREATE):
            raise Forbidden
        if "id" in data:
            data.pop("id")
    if request.method == "PUT":
        if not current_session.user_.has_permission(permissions.PRICE_EDIT):
            raise Forbidden
        if "id" not in data or not identifier:
            raise BadRequest
    return jsonify(pricelist_controller.set_price(identifier, data))


@blueprint.route("/pricelist_old/price/<int:identifier>", methods=["DELETE"])
@login_required(permission=permissions.PRICE_DELETE)
def delete_price(current_session, identifier: int):
    pricelist_controller.delete_price(identifier)
    return "", NO_CONTENT
